<?php
namespace IPS\nexus\Gateway;

if ( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

class _Paystar extends \IPS\nexus\Gateway
{
	public function checkValidity( \IPS\nexus\Money $amount, \IPS\GeoLocation $billingAddress )
	{
		if($amount->currency != 'IRR')
		{
			return FALSE;
		}
		
		return parent::checkValidity( $amount, $billingAddress );
	}
	
	public function auth( \IPS\nexus\Transaction $transaction, $values, \IPS\nexus\Fraud\MaxMind\Request $maxMind = NULL, $recurrings = array() )
	{		
		$transaction->save();
		
		$description = "شناسه کاربری مشتری : " . $transaction->member->member_id;
		$description .= "\nنام کاربری مشتری : " . $transaction->member->name;
		$description .= "\nایمیل مشتری : " . $transaction->member->email;
		if(!empty($transaction->member->cm_phone))
			$description .= "\nتلفن مشتری : " . $transaction->member->cm_phone;
		$description .= "\nنام بسته انتخابی : " . $transaction->invoice->title;
		
		$data = array(
			round((string) $transaction->amount->amount), 
			(string) \IPS\Settings::i()->base_url . 'applications/nexus/interface/gateways/paystar.php?nexusTransactionId=' . $transaction->id,
			$description	
		);
		
		$res = $this->api($data);
		if(strlen($res['au']) > 5)
			\IPS\Output::i()->redirect("https://{$res['address']}/paying/{$res['au']}");				
	
		throw new \RuntimeException;
	}
		
	public function capture( \IPS\nexus\Transaction $transaction )
	{

	}
	
	public function settings( &$form )
	{
		$settings = json_decode( $this->settings, TRUE );
		$form->add( new \IPS\Helpers\Form\Text( 'paystar_pin', $settings['pin'], TRUE ) );
		$form->add( new \IPS\Helpers\Form\Select( 'paystar_bank', $settings['bank'], TRUE, array( 'options' => $this->paystarwsconfig()['bank'])));		
	}


	public function testSettings( $settings )
	{		
		return $settings;
	}
	
	public function api($data=array(), $verify=false)
	{	
		$settings = json_decode($this->settings, true);
		$ws_config = $this->paystarwsconfig();
		try 
		{
			$f = array(
				'amount' => $data[0]/10,
				'pin' => $settings['pin'],
				!empty($verify) ? 'transid' : 'callback' => $data[1] 
			);	
			
			if(empty($verify))
				$f = array_merge($f, array('bank'=>$settings['bank'],'description'=>$data[2])); 				

			$t = !empty($verify) ? 'verify' : 'create';
			
			$result = (string) \IPS\Http\Url::external("https://{$ws_config['address']}/api/{$t}/")->request()->post( $f );
			$result = !empty($verify) ? $result : array('au'=>$result, 'address'=>$ws_config['address']);
		}
		catch ( \ Exception $e) 
		{
			$result = '-116';
		} 

		return $result;
	}
	
    private function paystarwsconfig()
    {
		require_once(dirname(__FILE__) . '/../../../../../paystarconfig.php');	
		return $ws_config;
    }
}